@@ -1,18 +1,14 @@
 #!/bin/sh
 
 if [ "$IS_CONTAINER" != "" ]; then
-  if [ ! "$(command -v dep >/dev/null)" ]; then
-    go get -u github.com/golang/dep/cmd/dep
-  fi
-
-  dep check
-  dep ensure
+  go mod vendor
+  go mod verify
   git diff --exit-code
 else
   podman run --rm \
     --env IS_CONTAINER=TRUE \
     --volume "${PWD}:/go/src/github.com/openshift/installer:z" \
     --workdir /go/src/github.com/openshift/installer \
-    docker.io/openshift/origin-release:golang-1.10 \
+    docker.io/openshift/origin-release:golang-1.13 \
     ./hack/verify-vendor.sh "${@}"
-fi
\ No newline at end of file
+fi
